@@ -147,6 +147,15 @@ class Drillstring(SectionsMixin):
         """
         return sum(sec.compute_get_volume() for sec in self)
 
+    def compute_get_outside_volume(self):
+        """
+        Compute and get the outside volume of the pipes of the drill string only,
+        using outer diameter
+        :return: volume in FOOT^3
+        """
+        ds = self.get_a_copy_without_bit()
+        return sum(sec.compute_outer_volume_tj_adjusted() for sec in ds)
+
     def compute_get_body_volume(self):
         """
         Compute and get the body volume of the pipes of the drill string only,
